@@ -5,15 +5,17 @@ import typing
 from pathlib import Path
 from typing import TYPE_CHECKING, Any, Dict, Iterable, List, Optional, Sequence, TypeVar
 
-from pydantic import BaseModel, ValidationError
 from typing_extensions import Literal, TypedDict
 
 if TYPE_CHECKING:
-    from ..asgi import Kui as ASGIKui, HttpRequest as ASGIHttpRequest
-    from ..wsgi import Kui as WSGIKui, HttpRequest as WSGIHttpRequest
+    from ..asgi import HttpRequest as ASGIHttpRequest
+    from ..asgi import Kui as ASGIKui
+    from ..wsgi import HttpRequest as WSGIHttpRequest
+    from ..wsgi import Kui as WSGIKui
 
 from ..exceptions import RequestValidationError
 from ..parameters import _get_response_docs
+from ..pydantic_compatible import DEFINITIONS_KEY
 from . import specification as spec
 from .extra_docs import merge_openapi_info
 from .schema import schema_request_body, schema_response
@@ -145,8 +147,8 @@ class OpenAPI:
             func, "__docs_responses__", []
         )
         if parameters or request_body:
-            handler = application.exception_middleware.lookup_handler(
-                RequestValidationError(ValidationError([], BaseModel), "body")
+            handler = application.exception_middleware._lookup_exception_handler(
+                RequestValidationError
             )
             if handler is None:
                 raise RuntimeError
@@ -250,7 +252,7 @@ def _pop_definitions(d: Dict[str, Any]) -> Dict[str, spec.Schema]:
     definitions: Dict[str, Any] = {}
     for key, value in d.items():
         if key == "schema":
-            return value.pop("definitions", {})
+            return value.pop(DEFINITIONS_KEY, {})
 
         if isinstance(value, dict):
             definitions.update(_pop_definitions(value))
