@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import abc
+import inspect
 import operator
 import typing
 from copy import deepcopy
@@ -29,11 +30,21 @@ class NoRouteFound(Exception):
 
 
 class HttpRegister(typing.Generic[ViewType]):
+    """
+    shortcut for `self << HttpRoute(path, endpoint, name)`
+
+    example:
+    ```python
+        @routes.http("/path", name="endpoint-name")
+        class Endpoint(HttpViewType): ...
+    ```
+    """
+
     def __init__(self, routes: RouteRegisterMixin[ViewType]) -> None:
         self.__routes = routes
 
     @cached_property
-    def _required_method(self) -> typing.Callable[[str], MiddlewareType[ViewType]]:
+    def _required_method(self) -> typing.Callable[[str], MiddlewareType]:
         for origin_base in self.__orig_bases__:  # type: ignore
             if safe_issubclass(get_origin(origin_base), HttpRegister):
                 generic_type = get_args(origin_base)[0]
@@ -66,7 +77,7 @@ class HttpRegister(typing.Generic[ViewType]):
         path: str,
         *,
         name: typing.Optional[str] = "",
-        middlewares: typing.Iterable[typing.Callable[[ViewType], ViewType]] = [],
+        middlewares: typing.Iterable[MiddlewareType] = [],
         summary: str | None = None,
         description: str | None = None,
         tags: typing.Iterable[str] | None = None,
@@ -94,7 +105,7 @@ class HttpRegister(typing.Generic[ViewType]):
         path: str,
         *,
         name: typing.Optional[str] = "",
-        middlewares: typing.Iterable[typing.Callable[[ViewType], ViewType]] = [],
+        middlewares: typing.Iterable[MiddlewareType] = [],
         summary: str | None = None,
         description: str | None = None,
         tags: typing.Iterable[str] | None = None,
@@ -123,7 +134,7 @@ class HttpRegister(typing.Generic[ViewType]):
         path: str,
         *,
         name: typing.Optional[str] = "",
-        middlewares: typing.Iterable[typing.Callable[[ViewType], ViewType]] = [],
+        middlewares: typing.Iterable[MiddlewareType] = [],
         summary: str | None = None,
         description: str | None = None,
         tags: typing.Iterable[str] | None = None,
@@ -152,7 +163,7 @@ class HttpRegister(typing.Generic[ViewType]):
         path: str,
         *,
         name: typing.Optional[str] = "",
-        middlewares: typing.Iterable[typing.Callable[[ViewType], ViewType]] = [],
+        middlewares: typing.Iterable[MiddlewareType] = [],
         summary: str | None = None,
         description: str | None = None,
         tags: typing.Iterable[str] | None = None,
@@ -181,7 +192,7 @@ class HttpRegister(typing.Generic[ViewType]):
         path: str,
         *,
         name: typing.Optional[str] = "",
-        middlewares: typing.Iterable[typing.Callable[[ViewType], ViewType]] = [],
+        middlewares: typing.Iterable[MiddlewareType] = [],
         summary: str | None = None,
         description: str | None = None,
         tags: typing.Iterable[str] | None = None,
@@ -210,7 +221,7 @@ class HttpRegister(typing.Generic[ViewType]):
         path: str,
         *,
         name: typing.Optional[str] = "",
-        middlewares: typing.Iterable[typing.Callable[[ViewType], ViewType]] = [],
+        middlewares: typing.Iterable[MiddlewareType] = [],
         summary: str | None = None,
         description: str | None = None,
         tags: typing.Iterable[str] | None = None,
@@ -239,7 +250,7 @@ class HttpRegister(typing.Generic[ViewType]):
         path: str,
         *,
         name: typing.Optional[str] = "",
-        middlewares: typing.Iterable[typing.Callable[[ViewType], ViewType]] = [],
+        middlewares: typing.Iterable[MiddlewareType] = [],
         summary: str | None = None,
         description: str | None = None,
         tags: typing.Iterable[str] | None = None,
@@ -306,7 +317,7 @@ class RouteRegisterMixin(abc.ABC, typing.Generic[ViewType]):
         path: str,
         *,
         name: typing.Optional[str] = "",
-        middlewares: typing.Iterable[typing.Callable[[ViewType], ViewType]] = [],
+        middlewares: typing.Iterable[MiddlewareType] = [],
     ) -> typing.Callable[[ViewType], ViewType]:
         """
         shortcut for `self << SocketRoute(path, endpoint, name)`
@@ -329,6 +340,21 @@ class RouteRegisterMixin(abc.ABC, typing.Generic[ViewType]):
         return register
 
 
+def _set_tags(tags: typing.Iterable[str] | None = None):
+    def _set_tags_middleware(endpoint: ViewType) -> ViewType:
+        stupid_type_checker = endpoint
+        w: typing.Any
+        if inspect.ismethod(stupid_type_checker):
+            w = stupid_type_checker.__func__
+        else:
+            w = endpoint
+        all_tags = list(getattr(w, "__docs_tags__", [])) + list(tags or [])
+        setattr(w, "__docs_tags__", all_tags)
+        return endpoint
+
+    return _set_tags_middleware
+
+
 class Routes(
     typing.Sequence[BaseRoute[ViewType]],
     RouteRegisterMixin[ViewType],
@@ -341,22 +367,13 @@ class Routes(
         ],
         namespace: str = "",
         tags: typing.Iterable[str] | None = None,
-        http_middlewares: typing.Sequence[MiddlewareType[ViewType]] = [],
+        http_middlewares: typing.Sequence[MiddlewareType] = [],
         socket_middlewares: typing.Sequence[typing.Any] = [],
     ) -> None:
         self.namespace = namespace
         self._list: typing.List[BaseRoute[ViewType]] = []
         self._http_middlewares = list(http_middlewares)
-        self._http_middlewares.append(
-            lambda endpoint: (
-                setattr(  # type: ignore
-                    endpoint,
-                    "__docs_tags__",
-                    list(getattr(endpoint, "__docs_tags__", [])) + list(tags or []),
-                )
-                or endpoint
-            )
-        )
+        self._http_middlewares.append(_set_tags(tags))
         self._socket_middlewares = list(socket_middlewares)
         for route in iterable:
             _ = self << route
@@ -366,14 +383,11 @@ class Routes(
         ...
 
     @typing.overload
-    def __getitem__(self, index: slice) -> typing.NoReturn:
+    def __getitem__(self, index: slice) -> typing.List[BaseRoute[ViewType]]:
         ...
 
     def __getitem__(self, index):
-        if isinstance(index, int):
-            return self._list[index]
-        else:
-            raise TypeError("Slicing syntax is not allowed")
+        return self._list[index]
 
     def __len__(self) -> int:
         return len(self._list)
@@ -423,6 +437,9 @@ class Routes(
                 return wrapper
         ```
         """
+        if len(self) > 0:
+            raise RuntimeError("Can not append middleware after route")
+
         self._http_middlewares.append(middleware)
         return middleware
 
@@ -439,6 +456,9 @@ class Routes(
                 return wrapper
         ```
         """
+        if len(self) > 0:
+            raise RuntimeError("Can not append middleware after route")
+
         self._socket_middlewares.append(middleware)
         return middleware
 
@@ -466,8 +486,8 @@ class Router(RouteRegisterMixin[ViewType], typing.Generic[ViewType]):
     def __init__(
         self,
         routes: typing.Iterable[BaseRoute[ViewType]],
-        http_middlewares: typing.Sequence[MiddlewareType[ViewType]] = [],
-        socket_middlewares: typing.Sequence[MiddlewareType[ViewType]] = [],
+        http_middlewares: typing.Sequence[MiddlewareType] = [],
+        socket_middlewares: typing.Sequence[MiddlewareType] = [],
     ) -> None:
         self.http_tree = RadixTree[ViewType]()
         self.websocket_tree = RadixTree[ViewType]()
