@@ -43,29 +43,30 @@ async def test_openapi_page():
         name: str
 
     @app.router.http.get("/path/{name}")
-    async def path(name: str = Path(...)):
+    async def path(name: Annotated[str, Path(...)]):
         pass
 
     @app.router.http("/http-view")
     class HTTPClass(HttpView):
-        async def get(self) -> Annotated[Any, HTMLResponse[200]]:
+        @classmethod
+        async def get(cls) -> Annotated[Any, HTMLResponse[200]]:
             """
             ...
 
             ......
             """
 
-        async def post(
-            self,
-        ) -> Annotated[Any, JSONResponse[201, {}, Username]]:
+        @classmethod
+        async def post(cls) -> Annotated[Any, JSONResponse[201, {}, Username]]:
             """
             ...
 
             ......
             """
 
+        @classmethod
         async def delete(
-            self,
+            cls,
         ) -> Annotated[Any, {"204": {"description": HTTPStatus(204).description}}]:
             """
             ...
@@ -75,7 +76,7 @@ async def test_openapi_page():
 
     def just_middleware(endpoint):
         async def wrapper(
-            authorization: str = Header(..., description="JWT Token")
+            authorization: Annotated[str, Header(..., description="JWT Token")],
         ) -> Annotated[Any, {"401": {"description": HTTPStatus(401).description}}]:
             return await endpoint()
 
@@ -110,7 +111,6 @@ async def test_openapi_page():
             "/hello": {
                 "get": {
                     "summary": "hello",
-                    "description": "hello",
                     "responses": {
                         "200": {
                             "description": "Request fulfilled, document follows",
@@ -520,7 +520,7 @@ def test_openapi_single_function_summary_and_description():
         "get": {"summary": "Summary"}
     }
     assert openapi._generate_path(app, app.router.search("http", "/2")[1], "/") == {
-        "get": {"summary": "Summary", "description": "Description"}
+        "get": {"summary": "Summary"}
     }
     assert openapi._generate_path(app, app.router.search("http", "/3")[1], "/") == {
         "get": {"summary": "Summary", "description": "Description"}
@@ -574,7 +574,7 @@ async def test_openapi_security():
 
     @app.router.http.get("/api-key")
     async def api_key(
-        api_key: Annotated[str, Depends(api_key_auth_dependency("api-key"))]
+        api_key: Annotated[str, Depends(api_key_auth_dependency("api-key"))],
     ):
         return api_key
 
@@ -665,7 +665,7 @@ def test_openapi_depend_response():
     app.router <<= "/docs" // openapi.routes
 
     async def get_current_user(
-        authorization: str = Header(..., description="JWT Token")
+        authorization: Annotated[str, Header(..., description="JWT Token")],
     ) -> Annotated[Any, {"401": {"description": HTTPStatus(401).description}}]:
         pass
 
@@ -754,9 +754,9 @@ def test_openapi_multi_type_responses():
         message: str
 
     @app.router.http.get("/")
-    async def homepage() -> Annotated[
-        Any, JSONResponse[200, {}, Message], HTMLResponse[200]
-    ]:
+    async def homepage() -> (
+        Annotated[Any, JSONResponse[200, {}, Message], HTMLResponse[200]]
+    ):
         pass
 
     assert openapi._generate_path(app, app.router.search("http", "/")[1], "/") == {
@@ -781,3 +781,87 @@ def test_openapi_multi_type_responses():
             }
         }
     }
+
+
+@pytest.mark.asyncio
+async def test_openapi_components_schemas():
+    app = Kui()
+    openapi = OpenAPI()
+    app.router <<= Routes("/docs" // openapi.routes, namespace="docs")
+
+    class M(BaseModel):
+        message: str
+
+    class N(BaseModel):
+        m: M
+
+    @app.router.http.get("/hello")
+    async def hello() -> Annotated[Any, JSONResponse[200, {}, N]]:
+        """
+        hello
+        """
+        pass
+
+    client = TestClient(app)
+    response = await client.get("/docs/json")
+    assert response.status_code == 200
+    assert len(response.headers["hash"]) == 32
+
+    openapi_docs_text = response.text
+    assert json.loads(openapi_docs_text) == {
+        "openapi": "3.0.3",
+        "info": {"title": "Kuí API", "version": "1.0.0"},
+        "paths": {
+            "/hello": {
+                "get": {
+                    "summary": "hello",
+                    "responses": {
+                        "200": {
+                            "description": "Request fulfilled, document follows",
+                            "headers": {},
+                            "content": {
+                                "application/json": {
+                                    "schema": {
+                                        "properties": {
+                                            "m": {"$ref": "#/components/schemas/M"}
+                                        },
+                                        "required": ["m"],
+                                        "type": "object",
+                                    }
+                                }
+                            },
+                        }
+                    },
+                }
+            }
+        },
+        "tags": [],
+        "components": {
+            "schemas": {
+                "M": {
+                    "properties": {"message": {"title": "Message", "type": "string"}},
+                    "required": ["message"],
+                    "title": "M",
+                    "type": "object",
+                }
+            }
+        },
+        "servers": [
+            {"url": "/", "description": "Current server"},
+            {
+                "url": "{scheme}://{address}/",
+                "description": "Custom API Server Host",
+                "variables": {
+                    "scheme": {
+                        "default": "http",
+                        "enum": ["http", "https"],
+                        "description": "http or https",
+                    },
+                    "address": {
+                        "default": "localhost",
+                        "description": "api server's host[:port]",
+                    },
+                },
+            },
+        ],
+    }, openapi_docs_text
