@@ -1,11 +1,9 @@
-from __future__ import annotations
-
 import pytest
 from async_asgi_testclient import TestClient
+from typing_extensions import Annotated
 
-from kui.asgi import HttpRoute, HttpView
+from kui.asgi import HttpRoute, HttpView, Kui, Path, Query, required_method
 from kui.asgi import MultimethodRoutes as Routes
-from kui.asgi import required_method
 from kui.utils import safe_issubclass
 
 
@@ -107,8 +105,6 @@ def test_mulitmethodroutes_with_prefix():
 
 @pytest.mark.asyncio
 async def test_mulitmethodroutes_with_parameters():
-    from kui.asgi import Kui, Path
-
     routes = Routes(base_class=HttpView)
 
     @routes.http.get("/{name}", name=None)
@@ -116,8 +112,11 @@ async def test_mulitmethodroutes_with_parameters():
     @routes.http.put("/{name}", name=None)
     @routes.http.patch("/{name}", name=None)
     @routes.http.delete("/{name}", name=None)
-    async def name(name: str = Path(...)):
-        return name
+    async def name(
+        name: Annotated[str, Path()],
+        status: Annotated[int, Query(200)],
+    ):
+        return name, status
 
     app = Kui(routes=routes)
 
@@ -125,5 +124,9 @@ async def test_mulitmethodroutes_with_parameters():
         resp = await client.get("/aber")
         assert resp.text == "aber"
 
+        resp = await client.post("/aber", query_string={"status": 201})
+        assert resp.status_code == 201
+        assert resp.text == "aber"
+
         resp = await client.get("/")
         assert resp.status_code == 404
