@@ -1,5 +1,9 @@
 from __future__ import annotations
 
+import functools
+
+import pytest
+
 
 def test_decorator():
     from kui.asgi import Kui
@@ -163,3 +167,38 @@ def test_empty_path():
         return "homepage"
 
     assert app.router.search("http", "/")[0] == {}
+
+
+def test_routes_slice():
+    from kui.asgi import HttpRoute, Routes
+
+    async def endpoint():
+        pass
+
+    routes = Routes(
+        HttpRoute("/login", endpoint),
+        HttpRoute("/register", endpoint),
+    )
+
+    assert routes[:] == routes
+    assert routes[1:] == [routes[1]]
+
+
+def test_middleware_check_wraps():
+    from kui.asgi import HttpRoute
+
+    async def endpoint():
+        return "hello world"
+
+    def middleware(endpoint):
+        @functools.wraps(endpoint)
+        async def wrapped():
+            return endpoint()
+
+        return wrapped
+
+    with pytest.raises(
+        RuntimeError,
+        match="Cannot use `@functools.wraps` on a middleware.",
+    ):
+        _ = HttpRoute("/hello", endpoint) @ middleware
